# mypy-boto3-fsx

[![PyPI - mypy-boto3-fsx](https://img.shields.io/pypi/v/mypy-boto3-fsx.svg?color=blue)](https://pypi.org/project/mypy-boto3-fsx)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-fsx.svg?color=blue)](https://pypi.org/project/mypy-boto3-fsx)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.FSx 1.17.36](https://boto3.amazonaws.com/v1/documentation/api/1.17.36/reference/services/fsx.html#FSx) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-fsx](#mypy-boto3-fsx)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `FSx` service.

```bash
python -m pip install boto3-stubs[fsx]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[fsx]` in your environment: `python -m pip install 'boto3-stubs[fsx]'`

Both type checking and auto-complete should work for `FSx` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[fsx]` in your environment: `python -m pip install 'boto3-stubs[fsx]'`

Both type checking and auto-complete should work for `FSx` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[fsx]` in your environment: `python -m pip install 'boto3-stubs[fsx]'`
- Run `mypy` as usual

Type checking should work for `FSx` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[fsx]` in your environment: `python -m pip install 'boto3-stubs[fsx]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `FSx` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`FSxClient` provides annotations for `boto3.client("fsx")`.

```python
import boto3

from mypy_boto3_fsx import FSxClient

client: FSxClient = boto3.client("fsx")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: FSxClient = session.client("fsx")
```

### Paginators annotations

`mypy_boto3_fsx.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_fsx import FSxClient
from mypy_boto3_fsx.paginator import (
    DescribeBackupsPaginator,
    DescribeFileSystemsPaginator,
    ListTagsForResourcePaginator,
)

client: FSxClient = boto3.client("fsx")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_backups_paginator: DescribeBackupsPaginator = client.get_paginator("describe_backups")
describe_file_systems_paginator: DescribeFileSystemsPaginator = client.get_paginator("describe_file_systems")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
```







### Typed dictionations

`mypy_boto3_fsx.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_fsx.type_defs import (
    ActiveDirectoryBackupAttributesTypeDef,
    AdministrativeActionFailureDetailsTypeDef,
    AdministrativeActionTypeDef,
    AliasTypeDef,
    BackupFailureDetailsTypeDef,
    BackupTypeDef,
    CompletionReportTypeDef,
    DataRepositoryConfigurationTypeDef,
    DataRepositoryFailureDetailsTypeDef,
    DataRepositoryTaskFailureDetailsTypeDef,
    DataRepositoryTaskStatusTypeDef,
    DataRepositoryTaskTypeDef,
    DeleteFileSystemLustreResponseTypeDef,
    DeleteFileSystemWindowsResponseTypeDef,
    FileSystemFailureDetailsTypeDef,
    LustreFileSystemConfigurationTypeDef,
    SelfManagedActiveDirectoryAttributesTypeDef,
    SelfManagedActiveDirectoryConfigurationTypeDef,
    SelfManagedActiveDirectoryConfigurationUpdatesTypeDef,
    TagTypeDef,
    WindowsFileSystemConfigurationTypeDef,
    AssociateFileSystemAliasesResponseTypeDef,
    CancelDataRepositoryTaskResponseTypeDef,
    CreateBackupResponseTypeDef,
    CreateDataRepositoryTaskResponseTypeDef,
    CreateFileSystemFromBackupResponseTypeDef,
    CreateFileSystemLustreConfigurationTypeDef,
    CreateFileSystemResponseTypeDef,
    CreateFileSystemWindowsConfigurationTypeDef,
    DataRepositoryTaskFilterTypeDef,
    DeleteBackupResponseTypeDef,
    DeleteFileSystemLustreConfigurationTypeDef,
    DeleteFileSystemResponseTypeDef,
    DeleteFileSystemWindowsConfigurationTypeDef,
    DescribeBackupsResponseTypeDef,
    DescribeDataRepositoryTasksResponseTypeDef,
    DescribeFileSystemAliasesResponseTypeDef,
    DescribeFileSystemsResponseTypeDef,
    FileSystemTypeDef,
    DisassociateFileSystemAliasesResponseTypeDef,
    FilterTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    UpdateFileSystemLustreConfigurationTypeDef,
    UpdateFileSystemResponseTypeDef,
    UpdateFileSystemWindowsConfigurationTypeDef,
)

def get_structure() -> ActiveDirectoryBackupAttributesTypeDef:
    return {
      ...
    }
```
